# Web Experience Toolkit (WET)

[![Build Status](https://secure.travis-ci.org/wet-boew/wet-boew.svg?branch=master)](http://travis-ci.org/wet-boew/wet-boew)
[![devDependency Status](https://david-dm.org/wet-boew/wet-boew/dev-status.svg)](https://david-dm.org/wet-boew/wet-boew#info=devDependencies)

[![Selenium Test Status](https://saucelabs.com/browser-matrix/wet-boew-bot.svg)](https://saucelabs.com/u/wet-boew-bot)

## What is the Web Experience Toolkit?

* An [award-winning](http://wet-boew.github.io/wet-boew/docs/ref/accolades-en.html#awards) front-end framework for building websites that are [accessible](http://wet-boew.github.io/wet-boew/index-en.html#accessibility), [usable](http://wet-boew.github.io/wet-boew/index-en.html#usability), [interoperable](http://wet-boew.github.io/wet-boew/index-en.html#interoperability), [mobile friendly](http://wet-boew.github.io/wet-boew/index-en.html#mobile-friendly-responsive-design) and [multilingual](http://wet-boew.github.io/wet-boew/index-en.html#multilingual)
* A collection of [flexible and themeable templates and reusable components](http://wet-boew.github.io/wet-boew/index-en.html#themeable-and-reusable)
* A [collaborative open source project led by the Government of Canada](http://wet-boew.github.io/wet-boew/index-en.html#collaborative-approach)

## Key resources

* [Documentation](http://wet-boew.github.io/wet-boew/docs/index-en.html)
* [Downloads](http://wet-boew.github.io/wet-boew/docs/versions/dwnld-en.html)
* [Examples](http://wet-boew.github.io/wet-boew/demos/index-en.html)
* [Version history](http://wet-boew.github.io/wet-boew/docs/versions/index-en.html) and [roadmap](http://wet-boew.github.io/wet-boew/docs/versions/rdmp-en.html)
* [Terms and conditions](http://wet-boew.github.io/wet-boew/License-en.html) (MIT license)
* [Source code repository](https://github.com/wet-boew/wet-boew/) and [contributing guidelines](http://wet-boew.github.io/wet-boew/docs/start-en.html#develop)
* [Communications material](http://wet-boew.github.io/wet-boew/docs/comms-en.html)
* [Websites using WET](http://wet-boew.github.io/wet-boew/docs/ref/wetsites-en.html)

## Benefits

### Accessibility

* Conforms to [WCAG 2.0](http://www.w3.org/TR/WCAG20/) level AA
* Leverages [WAI-ARIA](http://www.w3.org/TR/wai-aria/) to further enhance accessibility
* Assistive technology testing (Access Working Group)

### Usability

* Iterative approach to design
* Design patterns and usability testing (User Experience Working Group)

### Interoperability

* [HTML5](http://www.w3.org/TR/html5/)-first approach (leveraging native HTML5 support and filling support gaps with “polyfills”)
* Supporting a wide variety of browsers (IE, Firefox, Chrome, Safari, Opera)
* Building support for HTML data ([RDFa 1.1 Lite](http://www.w3.org/TR/rdfa-lite/), [Schema.org](http://www.schema.org/))

### Mobile friendly responsive design

* Adapts to different screen sizes and device capabilities
* Touchscreen support
* Optimized for performance
* Building support for device-based mobile applications

### Multilingual

* Currently supports 33 languages (including right-to-left languages)
  * English
  * French
  * Afrikaans
  * Albanian
  * Arabic
  * Armenian
  * Bulgarian
  * Chinese
  * Chinese (Simplified)
  * Czech
  * Dutch
  * Estonian
  * German
  * Greek
  * Hindi
  * Hungarian
  * Icelandic
  * Indonesian
  * Italian
  * Japanese
  * Korean
  * Latvian
  * Lithuanian
  * Polish
  * Portuguese
  * Portuguese (Brazilian)
  * Russian
  * Slovak
  * Spanish
  * Thai
  * Turkish
  * Ukranian
  * Vietnamese

### Themeable and reusable

* Flexible framework that supports custom themes
* Includes support for [2 different themes](http://wet-boew.github.io/wet-boew/docs/ref/themesstyle-en.html)
* Reusable templates, [plugins](http://wet-boew.github.io/wet-boew/docs/ref/plugins-en.html) and widgets
* [Adapted to various CMS and programming frameworks](http://wet-boew.github.io/wet-boew/docs/ref/variants-en.html) (Drupal, WordPress, SharePoint (in development), DotNetNuke (in development), PHP, SSI, Java/Maven)

### Reduces costs by openly sharing and collaborating

* Drives down research and development costs
* Avoids duplication of effort
* Produces better quality results

### Collaborative approach

* Project managed openly on GitHub, including discussion through the issues tracker
* Encouraging a free flow of ideas, dialogue and innovation including sharing of challenges and ideas
* External contributions welcome
  * Pull requests
  * Design patterns
  * Issues and suggestions
  * Documentation
  * Testing
* Multi-level review process for contributions to ensure code integrity (combination of automated and manual reviews)

-------------------------------------------------------------------

# Boîte à outils de l’expérience Web (BOEW)

## Qu’est-ce que la Boîte à outils de l’expérience Web?

* Une bibliothèque de code [primée](http://wet-boew.github.io/wet-boew/docs/ref/accolades-fr.html#primes) pour construire des sites Web [accessibles](http://wet-boew.github.io/wet-boew/index-fr.html#accessibilit), [faciles d'emploi](http://wet-boew.github.io/wet-boew/index-fr.html#facilit-demploi), [interopérables](http://wet-boew.github.io/wet-boew/index-fr.html#interoprabilit), [optimisés pour les appareils mobiles](http://wet-boew.github.io/wet-boew/index-fr.html#conception-optimise-pour-les-appareils-mobiles-et-ractive) et [multilingues](http://wet-boew.github.io/wet-boew/index-fr.html#multilingue)
* [Des modèles, ainsi que des composants réutilisables, qui sont flexibles et personnalisables](http://wet-boew.github.io/wet-boew/index-fr.html#personnalisable-et-rutilisable)
* Un [projet à source ouverte collaboratif dirigé par le Gouvernement du Canada](http://wet-boew.github.io/wet-boew/index-fr.html#approche-collaborative)

## Ressources clés

* [Documentation](http://wet-boew.github.io/wet-boew/docs/index-fr.html)
* [Téléchargements](http://wet-boew.github.io/wet-boew/docs/versions/dwnld-fr.html)
* [Exemples pratiques](http://wet-boew.github.io/wet-boew/demos/index-fr.html)
* [Historique des versions](http://wet-boew.github.io/wet-boew/docs/versions/index-fr.html) et [feuille de route](http://wet-boew.github.io/wet-boew/docs/versions/rdmp-fr.html)
* [Conditions régissant l'utilisation](http://wet-boew.github.io/wet-boew/Licence-fr.html) (licence MIT)
* [Dépôt de code source](https://github.com/wet-boew/wet-boew/) et [lignes directrices pour les contributeurs](http://wet-boew.github.io/wet-boew/docs/start-fr.html#develop)
* [Matériel de communications](http://wet-boew.github.io/wet-boew/docs/comms-fr.html)
* [Sites Web qui se servent de la BOEW](http://wet-boew.github.io/wet-boew/docs/ref/wetsites-fr.html)

## Avantages

### Accessibilité

* Conforme aux [Règles pour l'accessibilité des contenus Web (WCAG) 2.0](http://www.w3.org/Translations/WCAG20-fr/) niveau AA
* S'appuie sur [WAI-ARIA](http://www.w3.org/TR/wai-aria/) pour améliorer l'accessibilité
* Vérification avec les technologies d'assistance (Groupe de travail sur l'accessibilité)

### Facilité d'emploi

* Approche itérative pour la conception
* Patrons de conception et les essais de facilité d'emploi (Groupe de travail sur l'expérience des utilisateurs)

### Interopérabilité

* Approche centrée sur le [HTML5](http://www.w3.org/TR/html5/) (s'appuyant sur le soutien HTML5 natif et puis les &laquo;correctifs&raquo; pour résoudre les problèmes de soutien)
* Soutien pour plusieurs navigateurs (IE, Firefox, Chrome, Safari, Opera)
* Soutien en développement pour les données HTML ([RDFa 1.1 Lite](http://www.w3.org/TR/rdfa-lite/), [Schema.org](http://www.schema.org/))

### Conception optimisée pour les appareils mobiles et réactive

* S'adapte à différentes tailles d'écran et capacités d'appareil
* Soutien pour les écrans tactiles
* Optimisé pour les performances
* Soutien en développement pour les applications s’installant sur un appareil mobile

### Multilingue

* Soutien actuellement 33 langues (y compris les langues droite-à-gauche)
  * Anglais
  * Français
  * Afrikaans
  * Albanais
  * Allemand
  * Arabe
  * Arménien
  * Bulgare
  * Chinois
  * Chinois (simplifiée)
  * Coréen
  * Espagnol
  * Estonien
  * Grec
  * Hindi
  * Hongrois
  * Indonésien
  * Islandais
  * Italien
  * Japonais
  * Letton
  * Lituanien
  * Néerlandais
  * Polonais
  * Portugais
  * Portugais (brésilien)
  * Russe
  * Slovaque
  * Tchèque
  * Thaï
  * Turc
  * Ukrainien
  * Vietnamien

### Personnalisable et réutilisable

* Cadre flexible qui supporte des thèmes personnalisés
* Soutien [2 thèmes différents](http://wet-boew.github.io/wet-boew/docs/ref/themesstyle-fr.html)
* Modèles, [plugiciels](http://wet-boew.github.io/wet-boew/docs/ref/plugins-fr.html) et gadgets réutilisables
* [Adapté aux différents systèmes de gestion de contenu et cadres de programmation](http://wet-boew.github.io/wet-boew/docs/ref/variants-fr.html) (Drupal, WordPress, SharePoint (en développement), DotNetNuke (en développement), PHP, SSI, Java/Maven)

### Réduit les coûts en partageant et en collaborant ouvertement

* Réduit les coûts de recherche et de développement
* Évite la duplication des efforts
* Produit des résultats de meilleure qualité

### Approche collaborative

* Projet géré ouvertement sur GitHub, y compris les discussions à travers le système de suivi des questions
* Encourage la libre circulation des idées, du dialogue et de l'innovation, y compris le partage des défis et des idées
* Les contributions externes sont invités
  * Soumissions de code
  * Patrons de conception
  * Problèmes et suggestions
  * Documentation
  * Évaluations
* Processus d'examen sur plusieurs niveaux pour les contributions pour assurer l'intégrité du code (combinaison d'évaluations automatisées et manuelles)
